#
# spec file for package python-django-debug-toolbar
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-debug-toolbar
Version:        5.1.0
Release:        1.1
Summary:        A configurable set of panels that display various debug information
License:        BSD-3-Clause
URL:            https://github.com/jazzband/django-debug-toolbar
Source:         https://github.com/jazzband/django-debug-toolbar/archive/%{version}.tar.gz#/django-debug-toolbar-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 4.2.9}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module html5lib}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module sqlparse >= 0.2.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
Requires:       python-Django >= 4.2.9
Requires:       python-sqlparse >= 0.2.0
BuildArch:      noarch
%python_subpackages

%description
The Django Debug Toolbar is a configurable set of panels that display various
debug information about the current request/response and when clicked, display
more details about the panel's content.

Currently, the following panels have been written and are working:
 - Django version
 - Request timer
 - A list of settings in settings.py
 - Common HTTP headers
 - GET/POST/cookie/session variable display
 - Templates and context used, and their template paths
 - SQL queries including time to execute and links to EXPLAIN each query
 - List of signals, their args and receivers
 - Logging output via Python's built-in logging, or via the logbook module

There is also one Django management command currently:
 - debugsqlshell: Outputs the SQL that gets executed as you work in the Python
   interactive shell.

%prep
%setup -q -n django-debug-toolbar-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
export DJANGO_SETTINGS_MODULE=tests.settings
export DB_BACKEND=sqlite3
export DB_NAME=":memory:"
# test dependency `csp` not in openSUSE
rm tests/test_csp_rendering.py
%python_expand $python -m django test -v2 tests

%files %{python_files}
%license LICENSE
%doc README.rst docs/*.rst
%{python_sitelib}/debug_toolbar
%{python_sitelib}/django_debug_toolbar-%{version}.dist-info

%changelog
* Wed Apr 16 2025 Markéta Machová <mmachova@suse.com>
- update to 5.1.0
  * Raise the minimum Django version to 4.2
  * Fix DeprecationWarnings about form default templates
  * Fixed 'djdt' is not a registered namespace
  * Dark mode support
  * Added Python 3.13 to the CI matrix.
  * Removed support for Python 3.8 as it has reached end of life.
  * Added support for the LoginRequiredMiddleware introduced in Django 5.1.
  * Add Django 5.2 to tox matrix
  * Make show toolbar callback function async/sync compatible.
  * Refactor on csp_nonce usage with django-csp
  * more changes, see upstream changelog
* Fri Feb  9 2024 Markéta Machová <mmachova@suse.com>
- Update to 4.3
  4.3.0 (2024-02-01)
  * Dropped support for Django 4.0.
  * Added Python 3.12 to test matrix.
  * Removed outdated third-party panels from the list.
  * Avoided the unnecessary work of recursively quoting SQL parameters.
  * Postponed context process in templates panel to include lazy evaluated
    content.
  * Fixed template panel to avoid evaluating ``LazyObject`` when not already
    evaluated.
  * Added support for Django 5.0.
  * Refactor the ``utils.get_name_from_obj`` to simulate the behavior of
    ``django.contrib.admindocs.utils.get_view_name``.
  * Switched from black to the `ruff formatter
    <https://astral.sh/blog/the-ruff-formatter>`__.
  * Changed the default position of the toolbar from top to the upper top
    position.
  * Added the setting, ``UPDATE_ON_FETCH`` to control whether the
    toolbar automatically updates to the latest AJAX request or not.
    It defaults to ``False``.
  4.2.0 (2023-08-10)
  * Adjusted app directories system check to allow for nested template loaders.
  * Switched from flake8, isort and pyupgrade to `ruff
    <https://beta.ruff.rs/>`__.
  * Converted cookie keys to lowercase. Fixed the ``samesite`` argument to
    ``djdt.cookie.set``.
  * Converted ``StaticFilesPanel`` to no longer use a thread collector. Instead,
    it collects the used static files in a ``ContextVar``.
  * Added check ``debug_toolbar.W007`` to warn when JavaScript files are
    resolving to the wrong content type.
  * Fixed SQL statement recording under PostgreSQL for queries encoded as byte
    strings.
  * Patch the ``CursorWrapper`` class with a mixin class to support multiple
    base wrapper classes.
  4.1.0 (2023-05-15)
  * Improved SQL statement formatting performance.  Additionally, fixed the
    indentation of ``CASE`` statements and stopped simplifying ``.count()``
    queries.
  * Added support for the new STORAGES setting in Django 4.2 for static files.
  * Added support for theme overrides.
  * Reworked the cache panel instrumentation code to no longer attempt to undo
    monkey patching of cache methods, as that turned out to be fragile in the
    presence of other code which also monkey patches those methods.
  * Update all timing code that used :py:func:`time.time()` to use
    :py:func:`time.perf_counter()` instead.
  * Made the check on ``request.META["wsgi.multiprocess"]`` optional, but
    defaults to forcing the toolbar to render the panels on each request. This
    is because it's likely an ASGI application that's serving the responses
    and that's more likely to be an incompatible setup. If you find that this
    is incorrect for you in particular, you can use the ``RENDER_PANELS``
    setting to forcibly control this logic.
  4.0.0 (2023-04-03)
  * Added Django 4.2 to the CI.
  * Dropped support for Python 3.7.
  * Fixed PostgreSQL raw query with a tuple parameter during on explain.
  * Use ``TOOLBAR_LANGUAGE`` setting when rendering individual panels
    that are loaded via AJAX.
  * Add decorator for rendering toolbar views with ``TOOLBAR_LANGUAGE``.
  * Removed the logging panel. The panel's implementation was too complex, caused
    memory leaks and sometimes very verbose and hard to silence output in some
    environments (but not others). The maintainers judged that time and effort is
    better invested elsewhere.
  * Added support for psycopg3.
  * When ``ENABLE_STACKTRACE_LOCALS`` is ``True``, the stack frames' locals dicts
    will be converted to strings when the stack trace is captured rather when it
    is rendered, so that the correct values will be displayed in the rendered
    stack trace, as they may have changed between the time the stack trace was
    captured and when it is rendered.
  3.8.1 (2022-12-03)
  * Fixed release process by re-adding twine to release dependencies. No
    functional change.
  3.8.0 (2022-12-03)
  * Added protection against division by 0 in timer.js
  * Auto-update History panel for JavaScript ``fetch`` requests.
  * Support `HTMX boosting <https://htmx.org/docs/#boosting>`__ and
    `Turbo <https://turbo.hotwired.dev/>`__ pages.
  * Simplify logic for ``Panel.enabled`` property by checking cookies earlier.
  * Include panel scripts in content when ``RENDER_PANELS`` is set to True.
  * Create one-time mouseup listener for each mousedown when dragging the
    handle.
  * Update package metadata to use Hatchling.
  * Fix highlighting on history panel so odd rows are highlighted when
    selected.
  * Formalize support for Python 3.11.
  * Added ``TOOLBAR_LANGUAGE`` setting.
  3.7.0 (2022-09-25)
  * Added Profiling panel setting ``PROFILER_THRESHOLD_RATIO`` to give users
    better control over how many function calls are included. A higher value
    will include more data, but increase render time.
  * Update Profiling panel to include try to always include user code. This
    code is more important to developers than dependency code.
  * Highlight the project function calls in the profiling panel.
  * Added Profiling panel setting ``PROFILER_CAPTURE_PROJECT_CODE`` to allow
    users to disable the inclusion of all project code. This will be useful
    to project setups that have dependencies installed under
    ``settings.BASE_DIR``.
  * The toolbar's font stack now prefers system UI fonts. Tweaked paddings,
    margins and alignments a bit in the CSS code.
  * Only sort the session dictionary when the keys are all strings. Fixes a
    bug that causes the toolbar to crash when non-strings are used as keys.
* Fri Jun 16 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Sat Sep  3 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v3.6
  * Check if djdt-store-id is in all headers before usage
  * docs: Fix a few typos
  * Make Selenium tests pass, hopefully
  * Add Django 4.1 to classifiers
  * Remove signed_data_view decorator to support url type checking
  * Avoid assigning arbitrary attributes to SafeString instances
- from v3.5
  * Add the upcoming Django 4.1 to the CI matrix
  * Remove a couple of archived third-party repos
  * Replace OrderedDict
  * Do not crash when encountering unexpected data in the request
  * Cache panel work
  * Get PostgreSQL transaction tracking working
  * Add pyflame to the list of third-party panels
  * Fix cache panel miss counting
  * Stacktrace cleanups
  * Stack trace rework
  * Minor documentation updates
  * Reimplement HIDE_IN_STACKTRACES machinery
  * Rework similary/duplicate query grouping
  * Simplify SQLPanel._queries data structure
  * Tweak get_stack_trace() API
- from v3.4
  * The path may not always be a true path for stacktraces
  * Rename SQLPanel context var to control SQL access
- from 3.3
  * Drop support for Django 2.2 & 3.1
  * Added MrBenn Panel to Third Party Panels
  * Documentation fix in installation.rst
  * Don't raise W006 warning when app loader is specified
  * Move settings reset logic to settings module
  * Avoid installing middleware if Content-Encoding is set at all
  * Test middleware not injecting when Content-Encoding is set
  * Remove Python 3.6 due to EOL
  * Implement CacheStatTracker.get_or_set
  * Optimize render_stacktrace()
  * Remove unnecessary mock dependency
  * Optimize SQL reformatting
  * Fix USE_TZ RemovedInDjango50Warning
  * Duplicate the 'djdt' app_name to avoid importing toolbar early
  * unsigning history forms
  * adding a green flash to new rows in the history table on refresh
  * Adding Update on ajax feature
  * Order History panels requests descending chronologically
  * Single source 'djdt' app name
  * Various minor documentation fixes
  * Fix Docker instruction when host IP has more than 1 digit
  * Fix sql recording for async views
  * Preserve logs that LoggingPanel would previously overwrite
  * Fix and improve .assertValidHTML() test method
- from 3.2.4
  * Revert PR 1426 - PostGIS param stripping. This was removing
    leading and trailing characters from string typed parameters
    for postgres applications.
- from 3.2.3
  * Update translations and revert xgettext aliasing
  * Changed cache monkey-patching for Django 3.2+
  * Add check and docs for TEMPLATES APP_DIRS=False
  * Possibly fix an infinite recursion crash by avoid str() inside repr()
  * Fix transifex link (net -> com)
  * Add support for Python 3.10
  * Additional readme warning when using docker
  * Fix SQL selected / SQL explain for gis queries
  * Allow using ProfilingPanel as non last panel
  * Solve spelling mistake in documentation installation page
  * Fix test_param_conversion for Django 4.1 and mysql
  * Remove settings import from install instructions
  * Add a big warning regarding the security implications of changing
    SHOW_TOOLBAR_CALLBACK
  * Improve installation instructions
  * Fix settings docs
  * Update translations for a bunch of languages
  * Update DE locale
  * Discourage insecure SHOW_TOOLBAR_CALLBACK values
  * Create urls module and remove import package from docs
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.2.2
  * Use current_thread instead of currentThread method that was deprecated in
    Python 3.10 by @tirkarthi in #1465
  * Drop support for Django 3.0. by @hramezani in #1461
  * Support JS events when loading a panel. by @tim-schilling in #1441
  * Use twine to check generated package and readme by @francoisfreitag in
    [#1468]
  * Use default app config discovery by @francoisfreitag in #1467
  * Show template context on included templates by @gilmrjc in #1436
  * Keep the toolbar handle in bounds by @matthiask in #1472
  * Fixes #1239 by @saemideluxe in #1475
  * Extract common base cursor wrapper class by @jayaddison in #1479
  * updated Slovak translation by @eriktelepovsky in #1480
  * Fixes and improvements to history views by @ashwch in #1484
  * Add test coverage to ensure that SQL tracker wrappers are applied only once
    to database cursors by @jayaddison in #1478
  * Correct RENDER_PANELS functionality and when enabled disable HistoryPanel
    by @tim-schilling in #1440
  * Add: response status to HistoryPanel by @psacawa in #1490
  * Support for request-level urlconf overrides by @NielkS in #1488
* Sun May  9 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to v3.2.1
  * Fix CVE-2021-30459 by creating signature from all data fields
* Mon Jan 25 2021 John Vandenberg <jayvdb@gmail.com>
- Added docs/*.rst to docs
- Update to v3.2
  * Removed support for Django 1.11
  * See docs/changes.rst for other breaking changes
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2:
  * Removed support for end of life Django 2.0 and 2.1.
  * Added support for Python 3.8.
  * Add locals() option for sql panel.
  * Added support for Django 3.0
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1:
  * Changed the Travis CI matrix to run style checks first.
  * Exposed the djdt.init function too.
  * Small improvements to the code to take advantage of newer Django
    APIs and avoid warnings because of deprecated code.
  * Verified compatibility with the upcoming Django 3.0
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0:
  * Updated StaticFilesPanel to be compatible with Django 3.0.
  * The ProfilingPanel is now enabled but inactive by default.
  * Fixed toggling of table rows in the profiling panel UI.
  * The ProfilingPanel no longer skips remaining panels or middlewares.
  * Improved the installation documentation.
  * Fixed a possible crash in the template panel.
  * Added support for psycopg2 Composed objects.
  * Changed the Jinja2 tests to use Django's own Jinja2 template backend.
  * Added instrumentation to queries using server side cursors.
  * Removed support for Python 2.
  * Removed support for Django's deprecated MIDDLEWARE_CLASSES setting.
  Too many small improvements and cleanups to list them all.
- Remove merged patch t_integrations.patch
* Thu May 16 2019 Ondřej Súkup <mimi.vx@gmail.com>
- add t_integrations.patch to fix tests with django-2.2
* Wed Apr 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Export the lang to make sure we build on older openSUSE releases
* Tue Feb 19 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.11
  * Use ``defer`` on all ``<script>`` tags to avoid blocking HTML parsing,
    removed inline JavaScript.
  * Stop inlining images in CSS to avoid Content Security Policy errors
    altogether.
  * Reformatted the code using `black <https://github.com/ambv/black>`__.
  * Added the Django mail panel to the list of third-party panels.
  * Convert system check errors to warnings to accomodate exotic
    configurations.
  * Fixed a crash when explaining raw querysets.
  * Fixed an obscure unicode error with binary data fields.
  * Added MariaDB and Python 3.7 builds to the CI.
- from 1.10.1
  * Fixed a problem where the duplicate query detection breaks for
    non-hashable query parameters.
  * Added support for structured types when recording SQL.
  * Made Travis CI also run one test no PostgreSQL.
  * Added fallbacks for inline images in CSS.
  * Improved cross-browser compatibility around ``URLSearchParams`` usage.
  * Fixed a few typos and redundancies in the documentation, removed
    mentions of django-debug-toolbar's jQuery which aren't accurate
    anymore.
- from 1.10
  * Removed support for Django < 1.11.
  * Added support and testing for Django 2.1 and Python 3.7. No actual code
    changes were required.
  * Removed the jQuery dependency. This means that django-debug-toolbar
    now requires modern browsers with support for ``fetch``, ``classList``
    etc.
  * Added support for the server timing header.
  * Added a differentiation between similar and duplicate queries. Similar
    queries are what duplicate queries used to be (same SQL, different
    parameters).
  * Stopped hiding frames from Django's contrib apps in stacktraces by
    default.
  * Lots of small cleanups and bugfixes.
* Wed Aug  8 2018 tchvatal@suse.com
- Version update to 1.9.1:
  * Many many changes to list
  * Fix building with latest djangos
- Convert to singlespec
* Mon Mar 16 2015 mcihar@suse.cz
- Update to 1.3.0:
    New features
  * A new panel is available: Template Profiler.
  * The SHOW_TOOLBAR_CALLBACK accepts a callable.
  * The toolbar now provides a JavaScript API.
    Bugfixes
  * The toolbar handle cannot leave the visible area anymore when the toolbar is collapsed.
  * The root level logger is preserved.
  * The RESULTS_CACHE_SIZE setting is taken into account.
  * CSS classes are prefixed with djdt- to prevent name conflicts.
  * The private copy of jQuery no longer registers as an AMD module on sites that load RequireJS.
* Wed Jul 23 2014 mcihar@suse.cz
- Update to version 1.2.1:
  + See http://django-debug-toolbar.readthedocs.org/en/1.2/changes.html
    for full changelog
* Fri Nov  8 2013 speilicke@suse.com
- Update to version 0.10.2:
  + Upstream provides no changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Mar 13 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  Most of the license references point to the BSD-2-Clause on
  opensource.org but the COPYING file is BSD-3-Clause
* Mon Mar 12 2012 saschpe@gmx.de
- Fix typo, it's README.rst, not README.rs1
* Sat Mar 10 2012 saschpe@gmx.de
- Use upstream tarball
- Simplify macro usage
* Tue Jan 17 2012 alexandre@exatati.com.br
- Update to 0.9.4:
  - Sorry, no changelog.
* Fri Jan 13 2012 alexandre@exatati.com.br
- Update to 0.9.2:
  - Sorry,, no changelog.
* Wed Jan  4 2012 alexandre@exatati.com.br
- Update to 0.9.1:
  - Sorry, no changelog atm.
* Mon Apr 25 2011 alexandre@exatati.com.br
- Update to 0.8.5:
  - Sorry, no changelog.
- Regenerate spec file with py2pack.
* Tue Nov  9 2010 alexandre@exatati.com.br
- Update to 0.8.4;
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Wed Mar  3 2010 alexandre@exatati.com.br
- Update to 0.8.3.
* Tue Mar  2 2010 alexandre@exatati.com.br
- Update to 0.8.2.
* Wed Nov  4 2009 alexandre@exatati.com.br
- Update to 0.8.1;
- Building as noarch for openSUSE >= 11.2.
* Mon Sep 14 2009 alexandre@exatati.com.br
- Update to 0.8.0.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (0.7.0) for openSUSE.
